==> backup_elProd_2024_10_11.zip: elearning_2024_10_11/application/views/trainee/sequence/persalinterest.php <==
<input type="hidden" class="domain_select" value="<?php echo isset($PAVE_SEQUENCE) ? $PAVE_SEQUENCE : '' ?>">
<input type="hidden" class="current_module" id="current_module"  value="<?php echo isset($moduleloaded) ? $moduleloaded : "" ?>">
<input type="hidden" class="current_tracking_type" id="current_tracking_type" value="<?php echo isset($TRACKING_TYPE) ? $TRACKING_TYPE : '' ?>">
<input type="hidden" class="current_seuquence" id="current_seuquence">
<section class="content page-library">
    <div class="container">
        <!--------------------tab-------------------->
        <div class="tab-wrap row">
            <!--------------------tab-meu------------------>
            <div class="col-lg-3 position-relative">
                <div class="tab-nav-left">
                    <button class="tab-nav-toggle">
                        <i class="fa-solid fa-arrow-right"></i>
                    </button>    
                    <!--div class="tab-nav-header">
                        <h3><?php echo $this->lang->line('training_expression_new_expression_cat'); ?></h3>
                    </div-->        
                    <div class="tab-nav" id="navigation-library">    
                        <div class="button-container"> 
                            <?php
                                $nbrBtn    = 1;
                                if(isset($ret_newsletter2) && !empty($ret_newsletter2)){
                                    if(is_array($ret_newsletter2['module'])){
                                        $active_menu = '';
                                        foreach($ret_newsletter2['module'] as $key2=>$value2){
                                            if(is_array($value2)){ 
                                                $ident = str_replace(" ", "_", $key2);
                                                $identity = str_replace("-", "_", $ident);
                                                $keywordLabel = '';
                                                $active = '';
                                                foreach($value2 as $key3=>$value3){
                                                    $moduleContent = $this->sequence_model->getPavetSequenceHauts($key2,$value3['idg'],$value3['module_id'],$PAVE_SEQUENCE);
                                                    if ($nbrBtn == 1) {
                                                        $active .= 'active';
                                                    }
                                                    $keywordLabel .= ($this->session->userdata ('site_lang') == 'english' && $key2 == "Les conseils d'Anastasia") ? "Anastasia's Tips" : $key2;
                                                    echo ' <div class="button-inner"><button data-indice="normal" onclick="showDetailModule(this)" data-pave-id="'.$PAVE_SEQUENCE.'" data-groupe-id="'.$value3['idg'].'" data-module-id="'.$value3['module_id'].'" data-id="content-'.$nbrBtn.'" class="tablinks btn-module-'.$nbrBtn.' btn-mod '.$active.'">'.$keywordLabel.'</button><a href="#" onclick="showContentDropdown(this,event)" data-comportement="fade" class="btn-dropdown" data-content="content-'.$nbrBtn.'"><i class="bx bx-chevron-down"></i></a></div>
                                                        <div class="nav-dropdown container-dropdown" content="content-'.$nbrBtn.'">
                                                            <ul>';
                                                                foreach($moduleContent['module'] as $key4=>$value4){
                                                                    if(is_array($value4)){ $sequenceName = ''; foreach($value4 as $key5=>$value5){
                                                                            if($value5['sequence_name'] != "") { $sequenceName = ($this->session->userdata ('site_lang') == 'english' && $value5['sequence_name'] == "Articles REBONDIR") ? "Anastasia Autret's Tips" : $value5['sequence_name']; $sequenceUrl = $value5['sequence_url']; $idsequence = $value5['sequence_id']; $locsequence  = $value5['locs'];
                                                                                echo '<li><a href="#" class="dropdown-link" data-name="'.$sequenceName.'" data-id-module="'.$value3['module_id'].'" data-id-pave="'.$PAVE_SEQUENCE.'" data-sequence-id="'.$idsequence.'" onclick="loadContentSequence(this,event)">'.$sequenceName.'</a></li>';
                                                                            }
                                                                        }
                                                                    }
                                                                }
                                                        echo '</ul>
                                                        </div>';
                                                    $nbrBtn= $nbrBtn + 1;
                                                }
                                            }
                                        }
                                    }
                                }
                            ?>                                        
                        </div>                                       
                    </div>
                </div>
            </div>
            <div class="col-lg-9 position-relative"> 
                <div class="notification"></div>
                <div class="el-form-container mb-3">
                    <form action="<?php echo base_url() ?>search-data-library" id="search-data-library" method="post">
                        <input type="hidden" name="pave_sequence" value="<?php echo isset($PAVE_SEQUENCE) ? $PAVE_SEQUENCE : 6 ?>">
                        <div class="row justify-content-between">
                            <div class="col-sm-3 col-lg-3 mb-3 mb-sm-0">
                                <select name="dataType" id="dataType" class="el-form-select select-sort-by sort-by-type-data-pdg">
                                    <option value="Sequences" selected><?php echo $this->lang->line('other_user_sequences') ?></option>
                                    <option value="Link"><?php echo $this->lang->line('my_link_and_document_form_link_label_input') ?></option>
                                </select>
                            </div>
                            <div class="col-sm-6 col-lg-6">
                                <input type="text" class="el-form key-data-pdg" id="key-data-pdg" name="key-data-pdg" placeholder="<?php echo $this->lang->line('placeholder_search_doc_or_link') ?>" required minlength="3">
                            </div>
                            <div class="col-sm-3 col-lg-3">
                                <button type="submit" class="el-btn-icon el-btn-full el-btn-light">
                                    <i class="fa-solid fa-magnifying-glass"></i>
                                    <?php echo $this->lang->line('label_search') ?>
                                </button>
                            </div>
                        </div>  
                    </form>                  
                </div>
                <!--------------------tab-content------------------->    
                <div id="content-module-library" class="tab-content active">
                    <?php if (isset($dataLoadPageLibrary)) { ?>
                        <?php echo $dataLoadPageLibrary ?>
                    <?php } else { ?> 
                        <div class="row">
                            <div class="col-md-12 text-center">
                                <h4 class="nothing-data text-center">Pour commencer, veuiller selectionner un catégorie.</h4>
                            </div>
                        </div>
                    <?php } ?>
                </div>

                <div id="result-search-data" class="tab-content view-result-search">
                    <div class="tab-title title-active-menu-ch">
                        <h2 class="content_title_ch"><?php echo $this->lang->line('global_search_label') ?></h2>
                    </div>
                    <div id="view-all-result-search-data"></div>
                </div>

                <div id="content-011111" class="tab-content activite-datail"></div> 

                <div id="content-89848414" class="tab-content activite-view-content">
                    <div class="tab-title title-active-menu-pg">
                        <h2 class="content_title"><?php echo $this->lang->line('other_init_activity_title') ?></h2>
                    </div>
                    <div class="embed-responsive embed-responsive-16by9 iframe-sequence-activity-el">
                        <iframe class="embed-responsive-item iframeActivitySequence" allowfullscreen style="visibility:visible"></iframe>
                    </div>
                </div>  
            </div>
            <!--------------------/tab-meu------------------>
        </div><!-- .tab-wrap -->
    </div><!-- .container-fluid -->        
</section><!-- .content -->
<!-- .main-content-inner -->
<div class="modal" id="modal_elearning">
    <div class="modal-content">
        <div class="modal-header">
            <h5><?php echo $this->lang->line('modal_title_add_comment_init') ?> <span class="data-intitule-header"></span></h5>
            <button class="modal-close" data-dismiss="modal">
                <i class="fa-solid fa-x"></i>
            </button> 
        </div>
        <div class="modal-body">
            <div class="mb-4">
                <p class="error-saisie"></p>
                <input type="hidden" name="data-id" id="data-id">
                <input type="hidden" name="data-numero" id="data-numero">
                <input type="hidden" name="data-intitule" id="data-intitule">
                <input type="hidden" name="data-type" id="data-type" value="sequence_activite">
                <div class="content-comment-todo"></div>
            </div>

            <div class="mb-4">
                <label class="el-label" for=""><?php echo $this->lang->line('my_link_and_document_form_doc_label_comment') ?></label>
                <textarea class="el-form data-comment" id="data-comment" name="data-comment" rows="10" placeholder="Your comment"></textarea>
            </div>    

            <div class="modal-action">
                <a type="button" class="el-btn el-btn-blue btn-save-comment-pr">
                    <?php echo $this->lang->line('modal_btn_add') ?>
                </a>
                <button class="el-btn el-btn-pink" data-dismiss="modal">
                    <?php echo $this->lang->line('menu_rigth_btn_close') ?>
                </button>

            </div>
        </div>
    </div>
</div>
<div class="modal" id="alertConfirmModal">
    <div class="modal-content">
        <div class="modal-header">
            <h5><?php echo $this->lang->line('modal_confirm_title') ?></h5>
            <button class="modal-close" data-dismiss="modal">
                <i class="fa-solid fa-x"></i>
            </button> 
        </div>
        <div class="modal-body">
            <div class="mb-4">
                <p class="alert-confirmation"></p>
                <input type="hidden" name="idSequence" class="idSequence">
                <input type="hidden" name="numSequence" class="numSequence">
                <input type="hidden" name="urlFinalActivity" class="urlFinalActivity">
                <input type="hidden" name="status" class="status">
            </div>
            <div class="modal-action">
                <button type="button" class="el-btn el-btn-pink btn-resufe" data-dismiss="modal">
                    <?php echo $this->lang->line('modal_confirm_no') ?>
                </button>
                <button type="button" class="el-btn el-btn-blue btn-confirm-access-activity">
                    <?php echo $this->lang->line('modal_confirm_yes') ?>
                </button>
                <button type="button" class="el-btn el-btn-blue btn-confirm-ok" style="display: none;" data-dismiss="modal">
                    <?php echo $this->lang->line('modal_confirm_ok') ?>
                </button>


            </div>
        </div>
    </div>
</div>
<div class="modal" id="modal_classification_favoris">
    <div class="modal-content">
        <div class="modal-header">
            <h5>
                <?php echo $this->lang->line('modal_confirm_add_favorites'); ?>
            </h5>
            <button class="modal-close" data-dismiss="modal">
                <i class="fa-solid fa-x"></i>
            </button> 
        </div>
        <div class="modal-body">
            <form method="post" action="<?php echo base_url(); ?>classifySequence" id="form-classification-sequence">
                <input type="hidden" name="id_sequence" id="id_sequence" class="id_sequence">
                <input type="hidden" name="numero_sequence" id="numero_sequence" class="numero_sequence">
                <input type="hidden" name="intitle_seuquence" id="intitle_seuquence" class="intitle_seuquence">
                <input type="hidden" name="type_stat_programme" id="type_stat_programme" class="type_stat_programme" value="sequence_activite">
                <div class="mb-4">
                    <select class="el-form-select classification" id="classification" name="classification">
                        <?php foreach ($classification_favoris as $res) { ?>
                          <option value="<?php echo $res->id; ?>"><?php echo htmlentities($res->intitule); ?></option>
                        <?php } ?>
                    </select>
                </div>
                <div class="modal-action">
                    <button type="button" class="el-btn el-btn-blue btn-save-classification">
                        <?php echo $this->lang->line('modal_btn_classify'); ?>
                    </button>
                </div>
            </form>
        </div>
    </div>
</div>
<input type="hidden" name="url-stat-article" class="url-stat-article" value="<?php echo base_url(); ?>stat-article">
<input type="hidden" class="clsvaluepage" value="sequence_activite"> 
<script type="text/javascript">
  var infosAddError = "<?php echo $this->lang->line('training_expression_error_create'); ?>";
  var infosAddSuccess = "<?php echo $this->lang->line('training_expression_success_create'); ?>";
  var allExpression = "<?php echo $this->lang->line('glossary_all_expression_lbl_for'); ?>";
  var data_delete_ok = "<?php echo $this->lang->line('data_delete_ok'); ?>";
  var data_save_ok = "<?php echo $this->lang->line('data_save_ok'); ?>";
  var global_search_no_result_found = "<?php echo $this->lang->line('global_search_no_result_found'); ?>";
  var click_go_back = "<?php echo $this->lang->line('click_go_back'); ?>";
</script>

==> backup_elProd_2024_10_26.zip: elearning_2024_10_26/application/views/trainee/sequence/persalinterest.php <==
<input type="hidden" class="domain_select" value="<?php echo isset($PAVE_SEQUENCE) ? $PAVE_SEQUENCE : '' ?>">
<input type="hidden" class="current_module" id="current_module"  value="<?php echo isset($moduleloaded) ? $moduleloaded : "" ?>">
<input type="hidden" class="current_tracking_type" id="current_tracking_type" value="<?php echo isset($TRACKING_TYPE) ? $TRACKING_TYPE : '' ?>">
<input type="hidden" class="current_seuquence" id="current_seuquence">
<section class="content page-library">
    <div class="container">
        <!--------------------tab-------------------->
        <div class="tab-wrap row">
            <!--------------------tab-meu------------------>
            <div class="col-lg-3 position-relative">
                <div class="tab-nav-left">
                    <button class="tab-nav-toggle">
                        <i class="fa-solid fa-arrow-right"></i>
                    </button>    
                    <!--div class="tab-nav-header">
                        <h3><?php echo $this->lang->line('training_expression_new_expression_cat'); ?></h3>
                    </div-->        
                    <div class="tab-nav" id="navigation-library">    
                        <div class="button-container"> 
                            <?php
                                $nbrBtn    = 1;
                                if(isset($ret_newsletter2) && !empty($ret_newsletter2)){
                                    if(is_array($ret_newsletter2['module'])){
                                        $active_menu = '';
                                        foreach($ret_newsletter2['module'] as $key2=>$value2){
                                            if(is_array($value2)){ 
                                                $ident = str_replace(" ", "_", $key2);
                                                $identity = str_replace("-", "_", $ident);
                                                $keywordLabel = '';
                                                $active = '';
                                                foreach($value2 as $key3=>$value3){
                                                    $moduleContent = $this->sequence_model->getPavetSequenceHauts($key2,$value3['idg'],$value3['module_id'],$PAVE_SEQUENCE);
                                                    if ($nbrBtn == 1) {
                                                        $active .= 'active';
                                                    }
                                                    $keywordLabel .= ($this->session->userdata ('site_lang') == 'english' && $key2 == "Les conseils d'Anastasia") ? "Anastasia's Tips" : $key2;
                                                    echo ' <div class="button-inner"><button data-indice="normal" onclick="showDetailModule(this)" data-pave-id="'.$PAVE_SEQUENCE.'" data-groupe-id="'.$value3['idg'].'" data-module-id="'.$value3['module_id'].'" data-id="content-'.$nbrBtn.'" class="tablinks btn-module-'.$nbrBtn.' btn-mod '.$active.'">'.$keywordLabel.'</button><a href="#" onclick="showContentDropdown(this,event)" data-comportement="fade" class="btn-dropdown" data-content="content-'.$nbrBtn.'"><i class="bx bx-chevron-down"></i></a></div>
                                                        <div class="nav-dropdown container-dropdown" content="content-'.$nbrBtn.'">
                                                            <ul>';
                                                                foreach($moduleContent['module'] as $key4=>$value4){
                                                                    if(is_array($value4)){ $sequenceName = ''; foreach($value4 as $key5=>$value5){
                                                                            if($value5['sequence_name'] != "") { $sequenceName = ($this->session->userdata ('site_lang') == 'english' && $value5['sequence_name'] == "Articles REBONDIR") ? "Anastasia Autret's Tips" : $value5['sequence_name']; $sequenceUrl = $value5['sequence_url']; $idsequence = $value5['sequence_id']; $locsequence  = $value5['locs'];
                                                                                echo '<li><a href="#" class="dropdown-link" data-name="'.$sequenceName.'" data-id-module="'.$value3['module_id'].'" data-id-pave="'.$PAVE_SEQUENCE.'" data-sequence-id="'.$idsequence.'" onclick="loadContentSequence(this,event)">'.$sequenceName.'</a></li>';
                                                                            }
                                                                        }
                                                                    }
                                                                }
                                                        echo '</ul>
                                                        </div>';
                                                    $nbrBtn= $nbrBtn + 1;
                                                }
                                            }
                                        }
                                    }
                                }
                            ?>                                        
                        </div>                                       
                    </div>
                </div>
            </div>
            <div class="col-lg-9 position-relative"> 
                <div class="notification"></div>
                <div class="el-form-container mb-3">
                    <form action="<?php echo base_url() ?>search-data-library" id="search-data-library" method="post">
                        <input type="hidden" name="pave_sequence" value="<?php echo isset($PAVE_SEQUENCE) ? $PAVE_SEQUENCE : 6 ?>">
                        <div class="row justify-content-between">
                            <div class="col-sm-3 col-lg-3 mb-3 mb-sm-0">
                                <select name="dataType" id="dataType" class="el-form-select select-sort-by sort-by-type-data-pdg">
                                    <option value="Sequences"><?php echo $this->lang->line('other_user_sequences') ?></option>
                                    <option value="Link" selected><?php echo $this->lang->line('my_link_and_document_form_link_label_input') ?></option>
                                </select>
                            </div>
                            <div class="col-sm-6 col-lg-6">
                                <input type="text" class="el-form key-data-pdg" id="key-data-pdg" name="key-data-pdg" placeholder="<?php echo $this->lang->line('placeholder_search_doc_or_link') ?>" required minlength="3">
                            </div>
                            <div class="col-sm-3 col-lg-3">
                                <button type="submit" class="el-btn-icon el-btn-full el-btn-light">
                                    <i class="fa-solid fa-magnifying-glass"></i>
                                    <?php echo $this->lang->line('label_search') ?>
                                </button>
                            </div>
                        </div>  
                    </form>                  
                </div>
                <!--------------------tab-content------------------->    
                <div id="content-module-library" class="tab-content active">
                    <?php if (isset($dataLoadPageLibrary)) { ?>
                        <?php echo $dataLoadPageLibrary ?>
                    <?php } else { ?> 
                        <div class="row">
                            <div class="col-md-12 text-center">
                                <h4 class="nothing-data text-center">Pour commencer, veuiller selectionner un catégorie.</h4>
                            </div>
                        </div>
                    <?php } ?>
                </div>

                <div id="result-search-data" class="tab-content view-result-search">
                    <div class="tab-title title-active-menu-ch">
                        <h2 class="content_title_ch"><?php echo $this->lang->line('global_search_label') ?></h2>
                    </div>
                    <div id="view-all-result-search-data"></div>
                </div>

                <div id="content-011111" class="tab-content activite-datail"></div> 

                <div id="content-89848414" class="tab-content activite-view-content">
                    <div class="tab-title title-active-menu-pg">
                        <h2 class="content_title"><?php echo $this->lang->line('other_init_activity_title') ?></h2>
                    </div>
                    <div class="embed-responsive embed-responsive-16by9 iframe-sequence-activity-el">
                        <iframe class="embed-responsive-item iframeActivitySequence" allowfullscreen style="visibility:visible"></iframe>
                    </div>
                </div>  
            </div>
            <!--------------------/tab-meu------------------>
        </div><!-- .tab-wrap -->
    </div><!-- .container-fluid -->        
</section><!-- .content -->
<!-- .main-content-inner -->
<div class="modal" id="modal_elearning">
    <div class="modal-content">
        <div class="modal-header">
            <h5><?php echo $this->lang->line('modal_title_add_comment_init') ?> <span class="data-intitule-header"></span></h5>
            <button class="modal-close" data-dismiss="modal">
                <i class="fa-solid fa-x"></i>
            </button> 
        </div>
        <div class="modal-body">
            <div class="mb-4">
                <p class="error-saisie"></p>
                <input type="hidden" name="data-id" id="data-id">
                <input type="hidden" name="data-numero" id="data-numero">
                <input type="hidden" name="data-intitule" id="data-intitule">
                <input type="hidden" name="data-type" id="data-type" value="sequence_activite">
                <div class="content-comment-todo"></div>
            </div>

            <div class="mb-4">
                <label class="el-label" for=""><?php echo $this->lang->line('my_link_and_document_form_doc_label_comment') ?></label>
                <textarea class="el-form data-comment" id="data-comment" name="data-comment" rows="10" placeholder="Your comment"></textarea>
            </div>    

            <div class="modal-action">
                <a type="button" class="el-btn el-btn-blue btn-save-comment-pr">
                    <?php echo $this->lang->line('modal_btn_add') ?>
                </a>
                <button class="el-btn el-btn-pink" data-dismiss="modal">
                    <?php echo $this->lang->line('menu_rigth_btn_close') ?>
                </button>

            </div>
        </div>
    </div>
</div>
<div class="modal" id="alertConfirmModal">
    <div class="modal-content">
        <div class="modal-header">
            <h5><?php echo $this->lang->line('modal_confirm_title') ?></h5>
            <button class="modal-close" data-dismiss="modal">
                <i class="fa-solid fa-x"></i>
            </button> 
        </div>
        <div class="modal-body">
            <div class="mb-4">
                <p class="alert-confirmation"></p>
                <input type="hidden" name="idSequence" class="idSequence">
                <input type="hidden" name="numSequence" class="numSequence">
                <input type="hidden" name="urlFinalActivity" class="urlFinalActivity">
                <input type="hidden" name="status" class="status">
            </div>
            <div class="modal-action">
                <button type="button" class="el-btn el-btn-pink btn-resufe" data-dismiss="modal">
                    <?php echo $this->lang->line('modal_confirm_no') ?>
                </button>
                <button type="button" class="el-btn el-btn-blue btn-confirm-access-activity">
                    <?php echo $this->lang->line('modal_confirm_yes') ?>
                </button>
                <button type="button" class="el-btn el-btn-blue btn-confirm-ok" style="display: none;" data-dismiss="modal">
                    <?php echo $this->lang->line('modal_confirm_ok') ?>
                </button>


            </div>
        </div>
    </div>
</div>
<div class="modal" id="modal_classification_favoris">
    <div class="modal-content">
        <div class="modal-header">
            <h5>
                <?php echo $this->lang->line('modal_confirm_add_favorites'); ?>
            </h5>
            <button class="modal-close" data-dismiss="modal">
                <i class="fa-solid fa-x"></i>
            </button> 
        </div>
        <div class="modal-body">
            <form method="post" action="<?php echo base_url(); ?>classifySequence" id="form-classification-sequence">
                <input type="hidden" name="id_sequence" id="id_sequence" class="id_sequence">
                <input type="hidden" name="numero_sequence" id="numero_sequence" class="numero_sequence">
                <input type="hidden" name="intitle_seuquence" id="intitle_seuquence" class="intitle_seuquence">
                <input type="hidden" name="type_stat_programme" id="type_stat_programme" class="type_stat_programme" value="sequence_activite">
                <div class="mb-4">
                    <select class="el-form-select classification" id="classification" name="classification">
                        <?php foreach ($classification_favoris as $res) { ?>
                          <option value="<?php echo $res->id; ?>"><?php echo htmlentities($res->intitule); ?></option>
                        <?php } ?>
                    </select>
                </div>
                <div class="modal-action">
                    <button type="button" class="el-btn el-btn-blue btn-save-classification">
                        <?php echo $this->lang->line('modal_btn_classify'); ?>
                    </button>
                </div>
            </form>
        </div>
    </div>
</div>
<input type="hidden" name="url-stat-article" class="url-stat-article" value="<?php echo base_url(); ?>stat-article">
<input type="hidden" class="clsvaluepage" value="sequence_activite"> 
<script type="text/javascript">
  var infosAddError = "<?php echo $this->lang->line('training_expression_error_create'); ?>";
  var infosAddSuccess = "<?php echo $this->lang->line('training_expression_success_create'); ?>";
  var allExpression = "<?php echo $this->lang->line('glossary_all_expression_lbl_for'); ?>";
  var data_delete_ok = "<?php echo $this->lang->line('data_delete_ok'); ?>";
  var data_save_ok = "<?php echo $this->lang->line('data_save_ok'); ?>";
  var global_search_no_result_found = "<?php echo $this->lang->line('global_search_no_result_found'); ?>";
  var click_go_back = "<?php echo $this->lang->line('click_go_back'); ?>";
</script>
